===================================
oslo.service
===================================

Library for running OpenStack services

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/oslo.service
* Source: http://git.openstack.org/cgit/openstack/oslo.service
* Bugs: http://bugs.launchpad.net/oslo.service
